@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "notesagentnotedialog.h"
 #include "notesagent_debug.h"
@@ -39,7 +26,7 @@
 NotesAgentNoteDialog::NotesAgentNoteDialog(QWidget *parent)
     : QDialog(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowIcon(QIcon::fromTheme(QStringLiteral("knotes")));
 
@@ -66,7 +53,7 @@ NotesAgentNoteDialog::~NotesAgentNoteDialog()
 void NotesAgentNoteDialog::setNoteId(Akonadi::Item::Id id)
 {
     Akonadi::Item item(id);
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+    auto *job = new Akonadi::ItemFetchJob(item, this);
     job->fetchScope().fetchFullPayload(true);
     job->fetchScope().fetchAttribute< NoteShared::NoteDisplayAttribute >();
     connect(job, &Akonadi::ItemFetchJob::result, this, &NotesAgentNoteDialog::slotFetchItem);
@@ -78,7 +65,7 @@ void NotesAgentNoteDialog::slotFetchItem(KJob *job)
         qCDebug(NOTESAGENT_LOG) << "fetch item failed " << job->errorString();
         return;
     }
-    Akonadi::ItemFetchJob *itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
+    auto *itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
     const Akonadi::Item::List lstItem = itemFetchJob->items();
     if (!lstItem.isEmpty()) {
         const Akonadi::Item item = lstItem.first();
@@ -97,7 +84,7 @@ void NotesAgentNoteDialog::slotFetchItem(KJob *job)
             }
         }
         if (item.hasAttribute<NoteShared::NoteDisplayAttribute>()) {
-            const NoteShared::NoteDisplayAttribute *attr = item.attribute<NoteShared::NoteDisplayAttribute>();
+            const auto *attr = item.attribute<NoteShared::NoteDisplayAttribute>();
             if (attr) {
                 mNote->editor()->setTextColor(attr->backgroundColor());
                 //TODO add background color.
