@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "notesmanager.h"
 #include "notesharedglobalconfig.h"
@@ -24,7 +11,6 @@
 #include "attributes/notealarmattribute.h"
 #include "attributes/notedisplayattribute.h"
 #include "attributes/notelockattribute.h"
-#include "notesagentalarmdialog.h"
 
 #include <AkonadiCore/Session>
 #include <AkonadiCore/Collection>
@@ -47,8 +33,6 @@
 
 NotesManager::NotesManager(QObject *parent)
     : QObject(parent)
-    , mListener(nullptr)
-    , mCheckAlarm(nullptr)
 {
     mSession = new Akonadi::Session("KNotes Session", this);
     mNoteRecorder = new NoteShared::NotesChangeRecorder(this);
@@ -143,7 +127,7 @@ void NotesManager::slotCheckAlarm()
 
     Akonadi::Item::List lst;
     for (const Akonadi::Item &item : qAsConst(mListItem)) {
-        const NoteShared::NoteAlarmAttribute *attrAlarm = item.attribute<NoteShared::NoteAlarmAttribute>();
+        const auto *attrAlarm = item.attribute<NoteShared::NoteAlarmAttribute>();
         if (attrAlarm) {
             if (attrAlarm->dateTime() < QDateTime::currentDateTime()) {
                 lst.append(item);
@@ -185,7 +169,7 @@ void NotesManager::slotAcceptConnection()
     QTcpSocket *s = mListener->nextPendingConnection();
 
     if (s) {
-        NoteShared::NotesNetworkReceiver *recv = new NoteShared::NotesNetworkReceiver(s);
+        auto *recv = new NoteShared::NotesNetworkReceiver(s);
         connect(recv, &NoteShared::NotesNetworkReceiver::sigNoteReceived, this, &NotesManager::slotNewNote);
     }
 }
@@ -193,13 +177,13 @@ void NotesManager::slotAcceptConnection()
 void NotesManager::slotNewNote(const QString &name, const QString &text)
 {
     KNotification::event(QStringLiteral("receivednotes"),
-		         QString(),
+                         QString(),
                          i18n("Note Received"),
                          QStringLiteral("knotes"),
                          nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_notes_agent"));
-    NoteShared::CreateNewNoteJob *job = new NoteShared::CreateNewNoteJob(this, nullptr);
+    auto *job = new NoteShared::CreateNewNoteJob(this, nullptr);
     //For the moment it doesn't support richtext.
     job->setRichText(false);
     job->setNote(name, text);
