@@ -1,21 +1,9 @@
 /*******************************************************************
  KNotes -- Notes for the KDE project
 
- Copyright (c) 1997-2013, The KNotes Developers
+ SPDX-FileCopyrightText: 1997-2013 The KNotes Developers
 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ SPDX-License-Identifier: GPL-2.0-or-later
 *******************************************************************/
 
 #include <config-knotes.h>
@@ -86,7 +74,7 @@ KNotesApp::KNotesApp(QWidget *parent)
     mDebugAkonadiSearch = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
 
     if (KNotesGlobalConfig::self()->autoCreateResourceOnStart()) {
-        NoteShared::LocalResourceCreator *creator = new NoteShared::LocalResourceCreator(this);
+        auto *creator = new NoteShared::LocalResourceCreator(this);
         creator->createIfMissing();
     }
 
@@ -171,7 +159,6 @@ KNotesApp::KNotesApp(QWidget *parent)
         actions->addAction(donateAction->objectName(), donateAction);
     }
 
-
     KStandardAction::preferences(this, &KNotesApp::slotPreferences,
                                  actionCollection());
     KStandardAction::keyBindings(this, &KNotesApp::slotConfigureAccels,
@@ -271,7 +258,7 @@ void KNotesApp::slotDeleteSelectedNotes()
     if (dlg->exec()) {
         const Akonadi::Item::List lst = dlg->selectedNotes();
         if (!lst.isEmpty()) {
-            Akonadi::ItemDeleteJob *deleteJob = new Akonadi::ItemDeleteJob(lst, this);
+            auto *deleteJob = new Akonadi::ItemDeleteJob(lst, this);
             connect(deleteJob, &KJob::result, this, &KNotesApp::slotNoteDeleteFinished);
         }
     }
@@ -323,7 +310,7 @@ void KNotesApp::slotRowInserted(const QModelIndex &parent, int start, int end)
 void KNotesApp::createNote(const Akonadi::Item &item)
 {
     if (item.hasPayload<KMime::Message::Ptr>() && !mNotes.contains(item.id())) {
-        KNote *note = new KNote(m_noteGUI, item, mDebugAkonadiSearch);
+        auto *note = new KNote(m_noteGUI, item, mDebugAkonadiSearch);
         mNotes.insert(item.id(), note);
         connect(note, &KNote::sigShowNextNote,
                 this, &KNotesApp::slotWalkThroughNotes);
@@ -349,7 +336,7 @@ void KNotesApp::updateSystray()
 
 void KNotesApp::newNote(const QString &name, const QString &text)
 {
-    NoteShared::CreateNewNoteJob *job = new NoteShared::CreateNewNoteJob(this, this);
+    auto *job = new NoteShared::CreateNewNoteJob(this, this);
     job->setRichText(KNotesGlobalConfig::self()->richText());
     job->setNote(name, text);
     job->start();
@@ -719,7 +706,7 @@ void KNotesApp::slotOpenFindDialog()
 
 void KNotesApp::fetchNotesFromCollection(const Akonadi::Collection &col)
 {
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(col);
+    auto *job = new Akonadi::ItemFetchJob(col);
     job->fetchScope().fetchFullPayload(true);
     job->fetchScope().fetchAttribute<NoteShared::NoteLockAttribute>();
     job->fetchScope().fetchAttribute<NoteShared::NoteDisplayAttribute>();
@@ -735,7 +722,7 @@ void KNotesApp::slotItemFetchFinished(KJob *job)
         return;
     }
 
-    Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
 
     const Akonadi::Item::List items = fetchJob->items();
     for (const Akonadi::Item &item : items) {
